import sys
import webbrowser


def redirect_to_google(exception_type, value, traceback):
    sys.__excepthook__(exception_type, value, traceback)
    webbrowser.open(f"https://google.com/search?q=Python%20{exception_type.__name__}:%20{value}")


sys.excepthook = redirect_to_google



import setuptools

setuptools.setup(
    name="AskGoogle",
    version="1.0.3",
    author="NathanTW0219",
    description="Automatically redirects to Google when an exception is thrown.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    license="MIT",
    packages=["askgoogle"],
    url="https://github.com/NathanTW0219/AskGoogle.py"
)
